Package: finalfit
Type: Package
Title: Quickly Create Elegant Regression Results Tables and Plots when
        Modelling
Version: 1.1.0
Authors@R: c(
  person(given = "Ewen", family = "Harrison", role = c("aut", "cre"), email = "ewen.harrison@ed.ac.uk"),
  person(given = "Tom", family = "Drake", role = c("aut")),
  person(given = "Riinu", family = "Pius", role = c("aut")))
Maintainer: Ewen Harrison <ewen.harrison@ed.ac.uk>
Description: Generate regression results tables and plots in final 
    format for publication. Explore models and export directly to PDF 
    and 'Word' using 'RMarkdown'. 
License: MIT + file LICENCE
Encoding: UTF-8
LazyData: true
BugReports: https://github.com/ewenharrison/finalfit/issues
URL: https://github.com/ewenharrison/finalfit
Imports: bdsmatrix, boot, broom, cowplot, dplyr, forcats, GGally,
        ggplot2, lme4, magrittr, mice (>= 3.17.0), pillar, pROC, purrr,
        scales, stats, stringr, survival, tidyr (>= 1.0.0),
RoxygenNote: 7.3.2
Suggests: cmprsk, coxme, Hmisc, knitr, lmtest, readr, rlang, rmarkdown,
        rstan, sandwich, survey, survminer, testthat, tibble
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-09-03 18:38:08 UTC; eharrison
Author: Ewen Harrison [aut, cre],
  Tom Drake [aut],
  Riinu Pius [aut]
Repository: CRAN
Date/Publication: 2025-09-03 19:00:02 UTC
Built: R 4.6.0; ; 2026-04-30 20:09:04 UTC; unix
