# Generated by roxygen2: do not edit by hand

S3method(extract_fit,coxme)
S3method(extract_fit,coxph)
S3method(extract_fit,crr)
S3method(extract_fit,glm)
S3method(extract_fit,glmerMod)
S3method(extract_fit,lm)
S3method(extract_fit,lmerMod)
S3method(extract_fit,stanfit)
S3method(ff_metrics,coxph)
S3method(ff_metrics,coxphlist)
S3method(ff_metrics,glm)
S3method(ff_metrics,glmerMod)
S3method(ff_metrics,glmlist)
S3method(ff_metrics,lm)
S3method(ff_metrics,lmerMod)
S3method(ff_metrics,lmlist)
S3method(fit2df,coxme)
S3method(fit2df,coxph)
S3method(fit2df,coxphlist)
S3method(fit2df,crr)
S3method(fit2df,crrlist)
S3method(fit2df,glm)
S3method(fit2df,glmboot)
S3method(fit2df,glmerMod)
S3method(fit2df,glmlist)
S3method(fit2df,lm)
S3method(fit2df,lmerMod)
S3method(fit2df,lmlist)
S3method(fit2df,mipo)
S3method(fit2df,stanfit)
S3method(fit2df,svyglmlist)
S3method(print,data.frame.ff)
export("%$%")
export("%<>%")
export("%>%")
export(boot_compare)
export(boot_predict)
export(catTestfisher)
export(check_recode)
export(coefficient_plot)
export(condense_fit)
export(coxphmulti)
export(coxphuni)
export(crrmulti)
export(crruni)
export(dependent_label)
export(extract_fit)
export(extract_labels)
export(extract_variable_label)
export(ff_column_totals)
export(ff_expand)
export(ff_formula)
export(ff_glimpse)
export(ff_interaction)
export(ff_label)
export(ff_merge)
export(ff_metrics)
export(ff_mode)
export(ff_newdata)
export(ff_parse_formula)
export(ff_percent_only)
export(ff_permute)
export(ff_plot)
export(ff_relabel)
export(ff_relabel_df)
export(ff_remove_p)
export(ff_remove_ref)
export(ff_row_totals)
export(ff_stratify_helper)
export(finalfit)
export(finalfit.coxph)
export(finalfit.glm)
export(finalfit.lm)
export(finalfit_column_totals)
export(finalfit_expand)
export(finalfit_formula)
export(finalfit_glimpse)
export(finalfit_interaction)
export(finalfit_label)
export(finalfit_merge)
export(finalfit_mode)
export(finalfit_newdata)
export(finalfit_percent_only)
export(finalfit_permute)
export(finalfit_plot)
export(finalfit_relabel)
export(finalfit_relabel_df)
export(finalfit_remove_p)
export(finalfit_remove_ref)
export(finalfit_row_totals)
export(fit2df)
export(format_n_percent)
export(glmmixed)
export(glmmulti)
export(glmmulti_boot)
export(glmuni)
export(hr_plot)
export(is.survival)
export(labels_to_column)
export(labels_to_level)
export(lmmixed)
export(lmmulti)
export(lmuni)
export(metrics_hoslem)
export(missing_compare)
export(missing_df)
export(missing_glimpse)
export(missing_pairs)
export(missing_pattern)
export(missing_plot)
export(missing_predictorMatrix)
export(or_plot)
export(p_tidy)
export(plot_title)
export(remove_intercept)
export(remove_labels)
export(rm_duplicate_labels)
export(rm_duplicates)
export(rm_empty_block)
export(round_tidy)
export(summary_df)
export(summary_factorlist)
export(summary_factorlist_stratified)
export(surv_plot)
export(svyglmmulti)
export(svyglmuni)
export(variable_type)
import(ggplot2)
import(mice)
import(survival)
importFrom(boot,boot)
importFrom(broom,tidy)
importFrom(dplyr,"%>%")
importFrom(forcats,fct_rev)
importFrom(magrittr,"%$%")
importFrom(magrittr,"%<>%")
importFrom(mice,make.predictorMatrix)
importFrom(pillar,new_pillar_type)
importFrom(purrr,pmap)
importFrom(stats,AIC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,confint.default)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,xtabs)
importFrom(tidyr,gather)
importFrom(utils,globalVariables)
